import React, { Fragment } from 'react'
import styled, { css } from 'styled-components'
import { th, Icon } from '@pubsweet/ui'

const parseFileSize = (size = 0) => {
  const kbSize = Math.floor(size / 1000)
  const mbSize = Math.floor(kbSize / 1000)
  const gbSize = Math.floor(mbSize / 1000)

  if (gbSize) {
    return `${gbSize} GB`
  } else if (mbSize) {
    return `${mbSize} MB`
  } else if (kbSize) {
    return `${kbSize} kB`
  }
  return `${size} bytes`
}

const File = ({ name = 'filename', size }) => (
  <FileRoot>
    <IconButton>
      <Icon primary size={3}>
        eye
      </Icon>
    </IconButton>
    <IconButton>
      <Icon primary size={3}>
        download
      </Icon>
    </IconButton>
    <FileName>{name}</FileName>
    <FileSize>{parseFileSize(size)}</FileSize>
  </FileRoot>
)

const Files = ({
  files: { manuscripts = [], coverLetter = [], supplementary = [] },
}) => (
  <Root>
    {manuscripts.length > 0 && (
      <Fragment>
        <Header>
          <span>Main manuscript</span>
          <div />
        </Header>
        {manuscripts.map(file => <File key={file.id} {...file} />)}
      </Fragment>
    )}
    {supplementary.length > 0 && (
      <Fragment>
        <Header>
          <span>Supplemetary files</span>
          <div />
        </Header>
        {supplementary.map(file => <File key={file.id} {...file} />)}
      </Fragment>
    )}
    {coverLetter.length > 0 && (
      <Fragment>
        <Header>
          <span>Supplemetary files</span>
          <div />
        </Header>
        {coverLetter.map(file => <File key={file.id} {...file} />)}
      </Fragment>
    )}
  </Root>
)

export default Files

// #region styled-component
const defaultText = css`
  color: ${th('colorPrimary')};
  font-family: ${th('fontHeading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const FileName = styled.span`
  ${defaultText};
`
const FileSize = FileName.extend`
  margin-left: ${th('subGridUnit')};
`

const IconButton = styled.div`
  align-items: center;
  display: flex;
  justify-content: center;
  margin: 0 ${th('subGridUnit')};
`

const FileRoot = styled.div`
  align-items: center;
  border: ${th('borderDefault')};
  display: flex;
  flex-direction: row;
  margin-bottom: ${th('subGridUnit')};
  padding: ${th('subGridUnit')};
`

const Header = styled.div`
  align-self: stretch;
  align-items: center;
  display: flex;
  flex-direction: row;

  & span {
    ${defaultText};
    margin-right: ${th('subGridUnit')};
    text-transform: uppercase;
  }

  & div {
    background: ${th('colorPrimary')};
    flex: 1;
    height: 1px;
  }
`

const Root = styled.div`
  align-items: flex-start;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
`
// #endregion
