import React from 'react'
import { isEmpty } from 'lodash'
import { th } from '@pubsweet/ui'
import styled from 'styled-components'

import { Authors, Expandable, Files } from './'

const defaultConflict = `
“Prevention is better than cure.” Well said and well understood! But there
    are certain types of headaches, which are part and parcel of you; gifted to
    you by birth! Sinus headache is one of them, unfortunately. Many say about
    sinus, “that which can not be cured, must be endured!’ You can control it,
    reduce its impact. Can it be ever eradicated? The answer is in the negative,
    as far as the present day medical research can take you! In sinus,
    invariably you have the headache, but every headache is not sinus! Sinus and
    nasal passage problems are the cause of headache, mostly! It is not that you`
const Conflict = ({ conflict = defaultConflict }) => <Text>{conflict}</Text>

const Abstract = ({ abstract }) => (
  <Text dangerouslySetInnerHTML={{ __html: abstract }} />
)

const ManuscriptDetails = ({
  collection,
  fragment: {
    conflicts,
    files = {},
    authors = [],
    metadata: { abstract = '' },
  },
}) => (
  <Root>
    <Expandable label="Details" startExpanded>
      {!!abstract && (
        <Expandable label="abstract">
          <Abstract abstract={abstract} />
        </Expandable>
      )}
      {conflicts.hasConflicts !== 'no' && (
        <Expandable label="Conflict of interest">
          <Conflict conflict={conflicts.conflict} />
        </Expandable>
      )}
      {authors.length > 0 && (
        <Expandable label="authors" startExpanded>
          <Authors authors={authors} />
        </Expandable>
      )}
      {!isEmpty(files) && (
        <Expandable label="files">
          <Files files={files} />
        </Expandable>
      )}
    </Expandable>
  </Root>
)

export default ManuscriptDetails

// #region styled-components
const Text = styled.span`
  color: ${th('colorPrimary')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const Root = styled.div`
  background-color: ${th('colorBackground')};
  border: ${th('borderDefault')};
  margin-top: calc(${th('subGridUnit')} * 2);
  transition: height 0.3s;
`
// #endregion
